CA01-Cl08
open | /cms/logout/ |
open | /admin/ |
type | id_username | admin
type | id_password | admin
clickAndWait | //input[@value='Iniciar sesión'] |
clickAndWait | link=Section |
clickAndWait | link=Añadir section |
type | id_slug | çñ
clickAndWait | _continue |
verifyTextPresent | Por favor, corrija los siguientes errores. |
verifyTextPresent | Introduzca un 'slug' válido, consistente en letras, números, guiones bajos o medios. |
type | id_name_es | CA01-Cl08
type | id_slug | not-the-same
clickAndWait | _continue |
verifyTextNotPresent | Introduzca un 'slug' válido, consistente en letras, números, guiones bajos o medios. |
verifyTextNotPresent | Por favor, corrija los siguientes errores. |
type | id_slug | not-the-same-
type | id_slug | not-the-same-longslug12234567890abcdefghijklmnopqrstuvwxyz
clickAndWait | _continue |
verifyTextNotPresent | Introduzca un 'slug' válido, consistente en letras, números, guiones bajos o medios. |
verifyTextNotPresent | Por favor, corrija los siguientes errores. |
clickAndWait | link=Borrar |
clickAndWait | //input[@value='Sí, estoy seguro'] |
clickAndWait | link=Terminar sesión |